@@ -2,7 +2,7 @@
 
 __author__ = """Yunseong Hwang"""
 __email__ = "kika1492@gmail.com"
-__version__ = "0.4.2"
+__version__ = "0.5.0"
 
 """
 from koapy.backend.daishin_cybos_plus.core.CybosPlusEntrypoint import (
@@ -38,7 +38,7 @@ from koapy.backend.kiwoom_open_api_plus.core.KiwoomOpenApiPlusTrInfo import (
 from koapy.backend.kiwoom_open_api_plus.core.KiwoomOpenApiPlusVersionUpdater import (
     KiwoomOpenApiPlusVersionUpdater,
 )
-from koapy.backend.kiwoom_open_api_plus.grpc.KiwoomOpenApiPlusTrayApplication import (
+from koapy.backend.kiwoom_open_api_plus.pyside2.KiwoomOpenApiPlusTrayApplication import (
     KiwoomOpenApiPlusTrayApplication,
 )
 """
@@ -50,7 +50,7 @@ __classes_to_export__ = {
     "koapy.backend.kiwoom_open_api_plus.core.KiwoomOpenApiPlusQAxWidget": [
         "KiwoomOpenApiPlusQAxWidget"
     ],
-    "koapy.backend.kiwoom_open_api_plus.grpc.KiwoomOpenApiPlusTrayApplication": [
+    "koapy.backend.kiwoom_open_api_plus.pyside2.KiwoomOpenApiPlusTrayApplication": [
         "KiwoomOpenApiPlusTrayApplication"
     ],
     "koapy.backend.kiwoom_open_api_plus.core.KiwoomOpenApiPlusError": [
@@ -106,6 +106,7 @@ __all__ = [
     "CybosPlusEntrypointProxy",
 ]
 
+
 # lazily import classes on attribute access
 # https://www.python.org/dev/peps/pep-0562/
 def __getattr__(name):
