@@ -15,6 +15,8 @@ class KiwoomOpenApiPlusDynamicCallable:
             self._signature.return_annotation is not Signature.empty
         )
 
+        self.__name__ = self._name
+
     def is_valid_return_type(self, result):
         if self._should_test_return_type and not isinstance(
             result, self._signature.return_annotation
@@ -22,13 +24,18 @@ class KiwoomOpenApiPlusDynamicCallable:
             return False
         return True
 
-    def __call__(self, *args, **kwargs):
-        ba = self._signature.bind(*args, **kwargs)
+    def call(self, *args, **kwargs):
+        try:
+            ba = self._signature.bind(*args, **kwargs)
+        except TypeError as e:
+            raise TypeError(
+                "Exception while binding arguments for function: %s" % self._name
+            ) from e
         ba.apply_defaults()
         result = self._control.dynamicCall(self._function, list(ba.args))
         if not self.is_valid_return_type(result):
             raise TypeError(
-                "Return type of %s was expected for function call %s(...), but %s was found."
+                "Return type of %s was expected for function call %s(...), but %s was found"
                 % (
                     self._signature.return_annotation,
                     self._name,
@@ -36,3 +43,6 @@ class KiwoomOpenApiPlusDynamicCallable:
                 )
             )
         return result
+
+    def __call__(self, *args, **kwargs):
+        return self.call(*args, **kwargs)
