@@ -13,20 +13,27 @@ class KiwoomOpenApiPlusServiceClient:
             host = config.get_string(
                 "koapy.backend.kiwoom_open_api_plus.grpc.host", "localhost"
             )
+            host = config.get_string(
+                "koapy.backend.kiwoom_open_api_plus.grpc.client.host", host
+            )
         if port is None:
             port = config.get_int("koapy.backend.kiwoom_open_api_plus.grpc.port")
+            port = config.get_int(
+                "koapy.backend.kiwoom_open_api_plus.grpc.client.port", port
+            )
 
         self._host = host
         self._port = port
         self._credentials = credentials
+        self._kwargs = kwargs
 
         self._target = self._host + ":" + str(self._port)
 
         if self._credentials is None:
-            self._channel = grpc.insecure_channel(self._target, **kwargs)
+            self._channel = grpc.insecure_channel(self._target, **self._kwargs)
         else:
             self._channel = grpc.secure_channel(
-                self._target, self._credentials, **kwargs
+                self._target, self._credentials, **self._kwargs
             )
 
         self._stub = KiwoomOpenApiPlusService_pb2_grpc.KiwoomOpenApiPlusServiceStub(
